var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { Component } from 'react';
import { Provider, connect } from 'react-redux';
import { store, persistor } from './store';
import { PersistGate } from 'redux-persist/integration/react';
// import './css';
import { Layout, Tabs, Card } from 'antd';
import Tree from './Tree';
import { FormView, SchemaView, UiSchemaView, FormDataView } from './views';
import NodeEditor from './Editor';
import Toolbar from './Toolbar';
import Settings from './Settings';
import openFormList from './remote/openFormList';
const { Header, Sider, Content } = Layout;
const { TabPane } = Tabs;
const { dispatch } = store;
class App extends Component {
    constructor() {
        super(...arguments);
        this.state = {
            collapsed: false,
            data: this.props.data,
            modal: null,
        };
        this.toggle = () => {
            this.setState({
                collapsed: !this.state.collapsed,
            });
        };
        this.setStore = ({ schema, uiSchema, formData }) => {
            dispatch({
                type: 'TREE_SET_TREE',
                payload: { schema, uiSchema },
            });
            dispatch({
                type: 'FORM_DATA_SET',
                payload: formData,
            });
        };
        this.handleSave = (config) => {
            const { formId, formName } = this.state;
            if (this.state.create) {
                if (this.props.onCreate) {
                    this.props.onCreate(Object.assign({ name: config.schema.title }, config));
                }
            }
            else {
                if (this.props.onSave) {
                    this.props.onSave(Object.assign({ id: formId, name: formName }, config));
                }
            }
        };
        this.handleSelect = (config) => {
            const { id, name, schema = { title: 'ofm' }, uiSchema = {}, formData = {} } = config || {};
            this.setStore({ schema, uiSchema, formData });
            this.setState({ create: !id, formId: id, formName: name });
        };
        this.openModal = () => {
            let m = openFormList(this.state.data, this.handleSelect);
            this.setState({ modal: m });
        };
    }
    UNSAFE_componentWillReceiveProps(nextProps) {
        if (nextProps.data !== this.props.data) {
            if (nextProps.data !== null && nextProps.data !== undefined && this.state.modal === null) {
                let m = openFormList(this.state.data, this.handleSelect);
                this.setState({
                    modal: m,
                    data: nextProps.data,
                });
            }
        }
    }
    componentDidUpdate(prevProps) {
        if (prevProps.data !== this.props.data) {
            this.setState({
                data: this.props.data,
            });
            if (this.props.data) {
            }
        }
    }
    render() {
        const { settings } = this.props;
        return (React.createElement(Layout, { style: { transform: 'rotate(0)' } },
            React.createElement(Sider, { trigger: null, collapsible: true, collapsed: this.state.collapsed, width: settings.leftSiderWidth, style: {
                    background: '#fff',
                    padding: 0,
                    overflow: 'auto',
                    boxShadow: '0 2px 3px 0 rgba(0, 0, 0, 0.2), 0 2px 3px 0 rgba(0, 0, 0, 0.2)',
                    height: '100vh',
                    position: 'fixed',
                    left: 0,
                } },
                React.createElement(Tabs, { defaultActiveKey: "0", size: "small" },
                    React.createElement(TabPane, { tab: "Editor", style: { padding: '8px' }, key: "0" },
                        React.createElement(Tree, null)),
                    React.createElement(TabPane, { tab: "Settings", style: { padding: '8px' }, key: "1" },
                        React.createElement(Settings, null)))),
            React.createElement(Layout, { style: { marginLeft: settings.leftSiderWidth } },
                React.createElement(Header, { style: { background: '#fff', padding: 0 } },
                    React.createElement(Toolbar, { onOpen: () => this.openModal(), onSave: this.handleSave })),
                React.createElement(Content, { style: { minHeight: 280, padding: '12px 8px', display: 'flex', flexWrap: 'wrap' } },
                    React.createElement(Card, { bordered: false, style: { width: settings.formWidth, margin: '12px 8px', display: 'inline-block', verticalAlign: 'top' } },
                        React.createElement(FormView, null)),
                    (settings.subViews || []).map((a) => {
                        const style = { margin: '12px 8px', width: 400, display: 'inline-block', verticalAlign: 'top', maxHeight: '800px', overflowY: 'scroll' };
                        switch (a) {
                            case 'schema':
                                return (React.createElement(Card, { key: "schema", title: "Schema", style: style },
                                    React.createElement(SchemaView, null)));
                            case 'uiSchema':
                                return (React.createElement(Card, { key: "uiSchema", title: "Ui Schema", style: style },
                                    React.createElement(UiSchemaView, null)));
                            case 'formData':
                                return (React.createElement(Card, { key: "formData", title: "Form Data", style: style },
                                    React.createElement(FormDataView, null)));
                            default:
                                return React.createElement("div", { key: "null" });
                        }
                    }))),
            React.createElement(Sider, { width: this.props.activeNodeKey ? settings.rightSiderWidth : 0, style: {
                    overflow: 'auto',
                    background: '#fff',
                    boxShadow: '0 2px 3px 0 rgba(0, 0, 0, 0.2), 0 2px 3px 0 rgba(0, 0, 0, 0.2)',
                    // position: 'fixed',
                    height: '100vh',
                } },
                React.createElement(NodeEditor, null))));
    }
}
const AppContainer = connect(({ activeNodeKey, settings }) => ({
    activeNodeKey,
    settings,
}))(App);
export default (_a) => {
    var props = __rest(_a, []);
    return (React.createElement(Provider, { store: store },
        React.createElement(PersistGate, { loading: null, persistor: persistor },
            React.createElement(AppContainer, Object.assign({}, props)))));
};
//# sourceMappingURL=App.js.map