import React from 'react';
import InlineEditor from '../InlineEditor';
import { connect } from 'react-redux';
import { Input, Icon, Popconfirm, Tooltip } from 'antd';
const { getNodeByRjsfId } = require('../core');
const { TextArea } = Input;
const ACTIVE_STYLE = { backgroundColor: '#bae7ff' };
class ExtendedInlineEditor extends InlineEditor {
    renderView() {
        return (React.createElement("span", { className: "fb-test", onClick: this.onStartEditing }, this.props.children));
    }
}
class InlineTextAreaEditor extends ExtendedInlineEditor {
    renderEditing() {
        return (React.createElement(TextArea, { ref: (r) => (this.input = r), value: this.state.value, onBlur: this.onCompleteEditing, onChange: this.onChange, autosize: true, onKeyUp: (e) => {
                if (e.keyCode === 27) {
                    this.onCancelEditing();
                }
            } }));
    }
}
const ButtonGroup = connect(null, (dispatch, { id }) => ({
    select: () => dispatch({ type: 'ACTIVE_NODE_KEY_SET_BY_RJSF_ID', payload: id }),
    remove: () => dispatch({ type: 'TREE_REMOVE_NODE_BY_RJSF_ID', payload: id }),
}))((props) => {
    const { select, remove, id } = props;
    return (React.createElement(Tooltip, { title: id, placement: "right" },
        React.createElement("a", { href: "#!" },
            React.createElement(Icon, { onClick: select, type: "select" })),
        React.createElement(Popconfirm, { title: `Remove ${id}?`, onConfirm: remove },
            React.createElement("a", { href: "#!" },
                React.createElement(Icon, { type: "delete" })))));
});
export function fieldTemplateConnector(FieldTemplate) {
    return connect(({ tree: { present }, activeNodeKey, settings: { isInlineMode } }, { id }) => {
        const n = getNodeByRjsfId(present, id);
        const active = n && n.key === activeNodeKey;
        return { tree: present, active, isInlineMode };
    }, (dispatch, { id, schema, uiSchema }) => ({
        updateTitle: (title) => dispatch({
            type: 'TREE_UPDATE_NODE_BY_RJSF_ID',
            payload: { rjsfId: id, nodeUpdate: { schema: Object.assign(Object.assign({}, schema), { title }) } },
        }),
        updateDescription: (description) => dispatch({
            type: 'TREE_UPDATE_NODE_BY_RJSF_ID',
            payload: { rjsfId: id, nodeUpdate: { schema: Object.assign(Object.assign({}, schema), { description }) } },
        }),
        updateHelp: (help) => dispatch({
            type: 'TREE_UPDATE_NODE_BY_RJSF_ID',
            payload: { rjsfId: id, nodeUpdate: { uiSchema: Object.assign(Object.assign({}, uiSchema), { 'ui:help': help }) } },
        }),
    }))((props) => {
        const { id, label, description, help, schema, updateTitle, updateDescription, updateHelp, active, classNames, isInlineMode, } = props;
        if (!isInlineMode)
            return React.createElement(FieldTemplate, Object.assign({}, props));
        const labelElement = label && (React.createElement(ExtendedInlineEditor, { value: label, onChange: updateTitle }, label));
        const descriptionElement = description && (React.createElement(InlineTextAreaEditor, { value: description.props.description, onChange: updateDescription }, description));
        const helpElement = help && (React.createElement(ExtendedInlineEditor, { value: help.props.help, onChange: updateHelp }, help));
        return (React.createElement("div", { className: classNames, style: active ? ACTIVE_STYLE : null },
            ['object', 'array'].includes(schema.type) ? null : (React.createElement("div", { className: "pull-right" },
                ' ',
                React.createElement(ButtonGroup, { id: id }),
                ' ')),
            React.createElement(FieldTemplate, Object.assign({ _label: label, _description: description, _help: help }, props, { classNames: null, label: labelElement, description: descriptionElement, help: helpElement }))));
    });
}
export function objectFieldTemplateConnector(ObjectFieldTemplate) {
    return connect(({ tree: { present }, activeNodeKey, settings: { isInlineMode } }, { idSchema }) => {
        const n = idSchema && idSchema.$id && getNodeByRjsfId(present, idSchema.$id);
        const active = n && n.key === activeNodeKey;
        return { tree: present, active, isInlineMode };
    }, (dispatch, { idSchema, schema }) => ({
        updateTitle: (title) => dispatch({
            type: 'TREE_UPDATE_NODE_BY_RJSF_ID',
            payload: { rjsfId: idSchema.$id, nodeUpdate: { schema: Object.assign(Object.assign({}, schema), { title }) } },
        }),
        updateDescription: (description) => dispatch({
            type: 'TREE_UPDATE_NODE_BY_RJSF_ID',
            payload: { rjsfId: idSchema.$id, nodeUpdate: { schema: Object.assign(Object.assign({}, schema), { description }) } },
        }),
    }))((props) => {
        const { idSchema, title, description, updateTitle, updateDescription, active, isInlineMode } = props;
        if (!isInlineMode)
            return React.createElement(ObjectFieldTemplate, Object.assign({}, props));
        const titleElement = title && (React.createElement("span", null,
            React.createElement(ExtendedInlineEditor, { value: title, onChange: updateTitle }, title),
            React.createElement("span", { className: "pull-right" },
                ' ',
                React.createElement(ButtonGroup, { id: idSchema.$id }),
                ' ')));
        const descriptionElement = description && (React.createElement(InlineTextAreaEditor, { value: description, onChange: updateDescription }, description));
        return (React.createElement("div", { style: active ? ACTIVE_STYLE : null },
            React.createElement(ObjectFieldTemplate, Object.assign({ _title: title, _description: description }, props, { title: titleElement, description: descriptionElement }))));
    });
}
//# sourceMappingURL=connectors.js.map