var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import React from 'react';
import { connect } from 'react-redux';
import { Row, Button, Tooltip, message, Select } from 'antd';
import { ActionTypes } from 'redux-undo';
function write(filename, json) {
    const a = window.document.createElement('a');
    a.href = window.URL.createObjectURL(new Blob([JSON.stringify(json, null, 2)], { type: 'application/json' }));
    a.download = `${filename}.json`;
    document.body.appendChild(a);
    a.click();
    document.body.removeChild(a);
}
function read(e) {
    var file = e.target.files[0];
    if (!file) {
        return;
    }
    var reader = new FileReader();
    const p = new Promise(function (resolve) {
        reader.onload = function (e) {
            var contents = e.target.result;
            resolve(contents);
        };
    });
    reader.readAsText(file);
    return p;
}
const buttonStyle = { marginLeft: 8 };
class Toolbar extends React.Component {
    constructor(props) {
        super(props);
        this.save = () => {
            const { name, schema, uiSchema } = this.props.tree.present[0];
            // write(name, { name, schema, uiSchema });
            const { onSave } = this.props;
            if (onSave) {
                onSave({ schema, uiSchema });
            }
        };
        this.open = (e) => __awaiter(this, void 0, void 0, function* () {
            const s = yield read(e);
            try {
                const { name, schema, uiSchema } = JSON.parse(s);
                this.props.setTree({ name, schema, uiSchema });
            }
            catch (e) {
                message.error('Invalid json file!');
            }
        });
        this.state = {};
    }
    render() {
        const { tree, undo, redo, settings, updateSettings, newForm, onOpen } = this.props;
        const { past, future } = tree;
        return (React.createElement(Row, null,
            React.createElement("input", { ref: (ref) => (this.loadFile = ref), type: "file", accept: "application/json", onChange: this.open, hidden: true }),
            React.createElement(Tooltip, { title: "Open" },
                React.createElement(Button, { style: buttonStyle, onClick: onOpen, icon: "folder-open" })),
            React.createElement(Tooltip, { title: "Save" },
                React.createElement(Button, { style: buttonStyle, onClick: this.save, icon: "save" })),
            React.createElement(Tooltip, { title: "Undo" },
                React.createElement(Button, { style: buttonStyle, onClick: undo, disabled: !past.length, icon: "left" })),
            React.createElement(Tooltip, { title: "Redo" },
                React.createElement(Button, { style: buttonStyle, onClick: redo, disabled: !future.length, icon: "right" })),
            React.createElement(Select, { mode: "multiple", style: { width: 290, marginLeft: 12 }, value: settings.subViews, onChange: updateSettings, placeholder: "Select sub views..." },
                React.createElement(Select.Option, { key: "schema" }, "Schema"),
                React.createElement(Select.Option, { key: "uiSchema" }, "Ui Schema"),
                React.createElement(Select.Option, { key: "formData" }, "Data"))));
    }
}
export default connect(({ tree, settings }) => ({ tree, settings }), (dispatch) => ({
    newForm: () => dispatch({
        type: 'TREE_CLEAR',
    }),
    setTree: (payload) => dispatch({
        type: 'TREE_SET_TREE',
        payload,
    }),
    undo: () => dispatch({ type: ActionTypes.UNDO }),
    redo: () => dispatch({ type: ActionTypes.REDO }),
    updateSettings: (subViews) => dispatch({
        type: 'SETTINGS_UPDATE',
        payload: { subViews },
    }),
}))(Toolbar);
//# sourceMappingURL=Toolbar.js.map