"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const antd_1 = require("antd");
const lodash_1 = require("lodash");
const { TextArea } = antd_1.Input;
const { Option } = antd_1.Select;
function _FormItemTemplate({ title, children }) {
    return (react_1.default.createElement(antd_1.Row, { className: "ant-form-item" },
        react_1.default.createElement(antd_1.Col, { className: "ant-form-item-label" },
            react_1.default.createElement("label", null, title)),
        react_1.default.createElement(antd_1.Col, { className: "ant-form-item-control-wrapper" }, children)));
}
exports._FormItemTemplate = _FormItemTemplate;
function FormItemTemplate({ title, children, remove }) {
    return (react_1.default.createElement(antd_1.List.Item, { actions: remove ? [react_1.default.createElement(antd_1.Button, { onClick: remove, size: "small", type: "danger", shape: "circle", icon: "close" })] : null },
        react_1.default.createElement(antd_1.List.Item.Meta, { title: title, description: children })));
}
exports.FormItemTemplate = FormItemTemplate;
class TimeThrottle extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.throttle = 1000;
        this.editing = react_1.default.createElement(antd_1.Icon, { type: "edit" });
        this.onChange = (value) => {
            if (this.state.timer) {
                clearTimeout(this.state.timer);
            }
            this.setState({
                value: value,
                timer: setTimeout(() => {
                    this.setState({ timer: null });
                    this.onSubmitValue(this.state.value);
                }, this.throttle),
            });
        };
        this.onBlur = () => {
            if (this.state.timer) {
                clearTimeout(this.state.timer);
            }
            this.setState({
                timer: null,
            });
            this.onSubmitValue(this.state.value);
        };
        this.onRemove = () => {
            if (this.state.timer) {
                clearTimeout(this.state.timer);
            }
            this.setState({
                timer: null,
            });
            this.onSubmitValue(undefined);
        };
        this.state = {
            timer: null,
            value: props.value,
        };
    }
    componentWillUnmount() {
        if (this.state.timer) {
            clearTimeout(this.state.timer);
            this.setState({ timer: null });
            this.onSubmitValue(this.state.value);
        }
    }
    componentWillReceiveProps(nextProps) {
        if (nextProps.value !== this.state.value) {
            if (this.state.timer) {
                clearTimeout(this.state.timer);
                // this.props.onChange(this.state.value);
            }
            this.setState({
                value: nextProps.value,
                timer: null,
            });
        }
    }
    onSubmitValue(value) {
        this.props.onChange(value);
    }
    render() {
        return null;
    }
}
class TimeThrottleInput extends TimeThrottle {
    render() {
        const _a = this.props, { title } = _a, rest = __rest(_a, ["title"]);
        return (react_1.default.createElement(FormItemTemplate, { title: react_1.default.createElement("span", null,
                title,
                this.state.timer ? this.editing : null), remove: this.onRemove },
            react_1.default.createElement(antd_1.Input, Object.assign({}, rest, { value: this.state.value, onChange: (e) => this.onChange(e.target.value), onBlur: this.onBlur }))));
    }
}
class TimeThrottleTextArea extends TimeThrottle {
    render() {
        const _a = this.props, { title } = _a, rest = __rest(_a, ["title"]);
        const titleElement = (react_1.default.createElement("span", null,
            title,
            this.state.timer ? this.editing : null));
        return (react_1.default.createElement(FormItemTemplate, { title: titleElement, remove: this.onRemove },
            react_1.default.createElement(TextArea, Object.assign({}, rest, { value: this.state.value, onChange: (e) => this.onChange(e.target.value), onBlur: this.onBlur }))));
    }
}
class TimeThrottleRange extends TimeThrottle {
    componentWillReceiveProps(nextProps) {
        if (nextProps.value[0] !== this.state.value[0] || nextProps.value[1] !== this.state.value[1]) {
            if (this.state.timer) {
                clearTimeout(this.state.timer);
                // this.props.onChange(this.state.value);
            }
            this.setState({
                value: nextProps.value,
                timer: null,
            });
        }
    }
    onSubmitValue(value) {
        if (!value) {
            this.props.onChange(value);
        }
        let [min, max] = value;
        if (typeof min === 'string') {
            if (min) {
                min = this.props.value[0];
            }
            else {
                min = undefined;
            }
        }
        if (typeof max === 'string') {
            if (max) {
                max = this.props.value[1];
            }
            else {
                max = undefined;
            }
        }
        this.props.onChange([min, max]);
    }
    render() {
        const { value: [min, max], timer, } = this.state;
        const { title } = this.props;
        const titleElement = (react_1.default.createElement("span", null,
            title,
            timer ? this.editing : null));
        return (react_1.default.createElement(FormItemTemplate, { title: titleElement, remove: this.onRemove },
            react_1.default.createElement(antd_1.InputNumber, { onChange: (n) => {
                    this.onChange([typeof n === 'string' && !n ? undefined : n, max]);
                }, value: min === 0 && max === undefined ? '' : min, style: { width: 100, textAlign: 'center' }, placeholder: "Minimum" }),
            react_1.default.createElement(antd_1.Input, { style: { width: 30, borderLeft: 0, pointerEvents: 'none', backgroundColor: '#fff' }, placeholder: "~", disabled: true }),
            react_1.default.createElement(antd_1.InputNumber, { onChange: (n) => {
                    this.onChange([min, typeof n === 'string' && !n ? undefined : n]);
                }, value: max, style: { width: 100, textAlign: 'center', borderLeft: 0 }, placeholder: "Maximum" })));
    }
}
const widgetMap = {
    boolean: {
        checkbox: 'CheckboxWidget',
        radio: 'RadioWidget',
        select: 'SelectWidget',
        hidden: 'HiddenWidget',
    },
    string: {
        text: 'TextWidget',
        password: 'PasswordWidget',
        // email: "EmailWidget",
        // hostname: "TextWidget",
        // ipv4: "TextWidget",
        // ipv6: "TextWidget",
        uri: 'URLWidget',
        'data-url': 'FileWidget',
        radio: 'RadioWidget',
        select: 'SelectWidget',
        textarea: 'TextareaWidget',
        hidden: 'HiddenWidget',
        date: 'DateWidget',
        datetime: 'DateTimeWidget',
        // "date-time": "DateTimeWidget",
        'alt-date': 'AltDateWidget',
        'alt-datetime': 'AltDateTimeWidget',
        color: 'ColorWidget',
        file: 'FileWidget',
    },
    number: {
        text: 'TextWidget',
        select: 'SelectWidget',
        updown: 'UpDownWidget',
        range: 'RangeWidget',
        radio: 'RadioWidget',
        hidden: 'HiddenWidget',
    },
    integer: {
        text: 'TextWidget',
        select: 'SelectWidget',
        updown: 'UpDownWidget',
        range: 'RangeWidget',
        radio: 'RadioWidget',
        hidden: 'HiddenWidget',
    },
    array: {
        select: 'SelectWidget',
        checkboxes: 'CheckboxesWidget',
        files: 'FileWidget',
    },
};
const widgets = lodash_1.default(widgetMap)
    .toPairs()
    .flatMap(([type, widgets]) => lodash_1.default(widgets)
    .toPairs()
    .map(([widget]) => [widget, type])
    .value())
    .groupBy('0')
    .toPairs()
    .map(([widget, types]) => [widget, types.map((a) => a[1])])
    .map(([widget, types]) => [
    types.length > 1 ? ({ type }) => types.includes(type) : ((t) => ({ type }) => type === t)(types[0]),
    widget,
])
    .map(([filter, widget]) => {
    switch (widget) {
        case 'select':
        case 'radio':
            return [(schema, uiSchema) => schema.enum && filter(schema, uiSchema), widget];
        default:
            return [filter, widget];
    }
})
    .value();
function type({ node: { schema }, updateSchema: update }) {
    const key = 'type';
    const title = 'Type';
    const availableTypes = ['string', 'number', 'integer', 'boolean'];
    if (!availableTypes.includes(schema.type))
        return [];
    const value = (schema || {})[key];
    return [
        null,
        react_1.default.createElement(FormItemTemplate, { key: key, title: title, remove: () => update({ [key]: undefined }) },
            react_1.default.createElement(antd_1.Select, { onChange: (value) => update({ [key]: value }), value: value, style: { width: '100%' } }, availableTypes.map((key) => (react_1.default.createElement(Option, { key: key }, key))))),
    ];
}
function title({ node: { schema }, updateSchema: update }) {
    const key = 'title';
    const title = 'Title';
    const value = (schema || {})[key];
    if (value === undefined) {
        return [
            react_1.default.createElement(antd_1.Menu.Item, { key: key, onClick: () => update({ [key]: '' }) }, title),
        ];
    }
    else {
        return [
            null,
            react_1.default.createElement(TimeThrottleInput, { key: key, title: title, value: value, onChange: (value) => update({ [key]: value || undefined }) }),
        ];
    }
}
function description({ node: { schema }, updateSchema: update }) {
    const key = 'description';
    const title = 'Description';
    const value = (schema || {})[key];
    if (value === undefined) {
        return [
            react_1.default.createElement(antd_1.Menu.Item, { key: key, onClick: () => update({ [key]: '' }) }, title),
        ];
    }
    else {
        return [
            null,
            react_1.default.createElement(TimeThrottleTextArea, { key: key, title: title, value: value, onChange: (value) => update({ [key]: value || undefined }), autosize: true }),
        ];
    }
}
class ClassNamesEditor extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.colSizes = ['sm', 'md', 'lg', 'xl'];
        this.style = { width: '100%' };
        this.onSliderChange = (value) => {
            const { value: classNames, col } = this.state;
            let found = false;
            let newClassNames = classNames
                .map((a) => {
                let [perfix, b, v] = a.split('-');
                if (perfix === 'col' && b === col && Number.isInteger(+v)) {
                    found = true;
                    return value ? `col-${b}-${value}` : '';
                }
                return a;
            })
                .filter((a) => a);
            if (!found && value) {
                newClassNames.push(`col-${col}-${value}`);
            }
            this.props.onChange(newClassNames.join(' '));
        };
        const value = [...new Set(this.props.value.split(' ').filter((a) => a))];
        const cols = this.extractCol(value);
        this.state = {
            col: cols.length ? cols[0][0] : 'md',
            value: value,
            options: value,
        };
    }
    componentWillReceiveProps(nextProps) {
        if (nextProps.value !== this.props.value) {
            const value = nextProps.value.split(' ').filter((a) => a);
            const { options } = this.state;
            const newOptions = value.filter((a) => !options.includes(a));
            this.setState({
                value,
                options: newOptions,
            });
        }
    }
    extractCol(classNames) {
        return classNames
            .filter((a) => a.startsWith('col-'))
            .map((a) => a.split('-'))
            .filter((a) => a.length === 3 && Number.isInteger(+a[2]) && this.colSizes.includes(a[1]))
            .map(([a, b, c]) => [b, +c]);
    }
    renderMenu() {
        return (react_1.default.createElement(antd_1.Menu, { onClick: ({ key }) => this.setState({ col: key }) }, this.colSizes.map((a) => (react_1.default.createElement(antd_1.Menu.Item, { key: a },
            "col-",
            a,
            "-")))));
    }
    sliderValue() {
        const { value, col } = this.state;
        return (this.extractCol(value).find((a) => a[0] === col) || [0, 0])[1];
    }
    render() {
        const _a = this.props, { title } = _a, rest = __rest(_a, ["title"]);
        const { options, value, col } = this.state;
        return (react_1.default.createElement(FormItemTemplate, { title: title, remove: () => this.props.onChange(undefined) },
            react_1.default.createElement(antd_1.Row, { type: "flex", align: "middle" },
                react_1.default.createElement(antd_1.Col, { xs: 4 },
                    react_1.default.createElement(antd_1.Dropdown, { overlay: this.renderMenu() },
                        react_1.default.createElement("a", null,
                            col,
                            " ",
                            react_1.default.createElement(antd_1.Icon, { type: "down" })))),
                react_1.default.createElement(antd_1.Col, { xs: 20 },
                    react_1.default.createElement(antd_1.Slider, { min: 0, max: 12, value: this.sliderValue(), onChange: this.onSliderChange }))),
            react_1.default.createElement(antd_1.Select, Object.assign({ style: this.style, mode: "tags", tokenSeparators: [' '] }, rest, { value: value, onChange: (value) => this.props.onChange(value.join(' ')), onBlur: this.onBlur }), options.map((a) => (react_1.default.createElement(Option, { key: a }, a))))));
    }
}
function classNames({ node: { uiSchema }, updateUiSchema: update }) {
    const key = 'classNames';
    const title = 'Class Names';
    const value = (uiSchema || {})[key];
    if (value === undefined) {
        return [
            react_1.default.createElement(antd_1.Menu.Item, { key: key, onClick: () => update({ [key]: '' }) }, title),
        ];
    }
    else {
        return [
            null,
            react_1.default.createElement(ClassNamesEditor, { key: key, title: title, value: value, onChange: (value) => update({ classNames: value }) }),
        ];
    }
}
function placeholder({ node: { schema, uiSchema }, updateUiOptions: update }) {
    if (schema.type === 'object' || schema.type === 'array') {
        return [];
    }
    const key = 'placeholder';
    const title = 'Placeholder';
    const uiOptions = (uiSchema || {})['ui:options'];
    const value = (uiOptions || {})[key];
    if (value === undefined) {
        return [
            react_1.default.createElement(antd_1.Menu.Item, { key: key, onClick: () => update({ [key]: '' }) }, title),
        ];
    }
    else {
        return [
            null,
            react_1.default.createElement(TimeThrottleInput, { key: key, title: title, value: value, onChange: (value) => update({ [key]: value }) }),
        ];
    }
}
function help({ node: { uiSchema }, updateUiSchema: update }) {
    const key = 'ui:help';
    const title = 'Help';
    const value = (uiSchema || {})[key];
    if (value === undefined) {
        return [
            react_1.default.createElement(antd_1.Menu.Item, { key: key, onClick: () => update({ [key]: '' }) }, title),
        ];
    }
    else {
        return [
            null,
            react_1.default.createElement(TimeThrottleInput, { key: key, title: title, value: value, onChange: (value) => update({ [key]: value }) }),
        ];
    }
}
function widget({ node: { schema, uiSchema }, updateUiSchema: update }) {
    const key = 'ui:widget';
    const title = 'Widget';
    const availableWidgets = widgets.filter(([f]) => f(schema || {}, uiSchema || {}));
    if (!availableWidgets.length)
        return [];
    const value = (uiSchema || {})[key];
    if (value === undefined) {
        return [
            react_1.default.createElement(antd_1.Menu.Item, { key: key, onClick: () => update({ [key]: '' }) }, title),
        ];
    }
    else {
        return [
            null,
            react_1.default.createElement(FormItemTemplate, { key: key, title: title, remove: () => update({ [key]: undefined }) },
                react_1.default.createElement(antd_1.Select, { onChange: (value) => update({ [key]: value || null }), value: value, style: { width: '100%' }, showSearch: true }, availableWidgets.map(([_, key]) => (react_1.default.createElement(Option, { key: key }, key))))),
        ];
    }
}
function pattern({ node: { schema }, updateSchema: update }) {
    if (schema.type !== 'string')
        return [];
    const key = 'pattern';
    const title = 'Pattern';
    const value = (schema || {})[key];
    if (value === undefined) {
        return [
            react_1.default.createElement(antd_1.Menu.Item, { key: key, onClick: () => update({ [key]: '' }) }, title),
        ];
    }
    else {
        return [
            null,
            react_1.default.createElement(TimeThrottleInput, { key: key, title: title, value: value, onChange: (value) => update({ [key]: value || undefined }) }),
        ];
    }
}
function required({ node: { schema }, updateSchema: update }) {
    const key = 'required';
    const title = 'Required';
    if (schema.type !== 'object')
        return [];
    if (!schema.required) {
        return [
            react_1.default.createElement(antd_1.Menu.Item, { key: key, onClick: () => update({ [key]: [] }) }, title),
        ];
    }
    return [
        null,
        react_1.default.createElement(FormItemTemplate, { key: key, title: "Required", remove: () => update({ [key]: undefined }) },
            react_1.default.createElement(antd_1.Select, { mode: "multiple", style: { width: '100%' }, onChange: (required) => update({ required }), value: schema.required }, Object.keys(schema.properties || {}).map((a) => (react_1.default.createElement(Option, { key: a }, a))))),
    ];
}
const rangeMeta = (match, key, title, minp, maxp) => ({ node: { schema }, updateSchema: update }) => {
    if (!match(schema))
        return [];
    if (schema[minp] === undefined && schema[maxp] === undefined) {
        return [
            react_1.default.createElement(antd_1.Menu.Item, { key: key, onClick: () => update({ [minp]: 0 }) }, title),
        ];
    }
    return [
        null,
        react_1.default.createElement(TimeThrottleRange, { key: key, title: title, value: [schema[minp], schema[maxp]], onChange: (value) => {
                if (!value) {
                    update({ [minp]: undefined, [maxp]: undefined });
                }
                else {
                    const [min, max] = value;
                    update({
                        [minp]: min ? min : max === undefined ? 0 : undefined,
                        [maxp]: max,
                    });
                }
            } }),
    ];
};
const length = rangeMeta((a) => a.type === 'string', 'length', 'Length', 'minLength', 'maxLength');
const range = rangeMeta((a) => a.type === 'number' || a.type === 'integer', 'range', 'Range', 'minimum', 'maximum');
const itemRange = rangeMeta((a) => a.type === 'array', 'itemRange', 'Item Range', 'minItems', 'maxItems');
function uniqueItems({ node: { schema }, updateSchema: update }) {
    const key = 'uniqueItems';
    const title = 'Unique Items';
    if (schema.type !== 'array')
        return [];
    if (schema[key] === undefined) {
        return [
            react_1.default.createElement(antd_1.Menu.Item, { key: key, onClick: () => update({ [key]: true }) }, title),
        ];
    }
    else {
        return [
            null,
            react_1.default.createElement(antd_1.List.Item, { actions: [
                    react_1.default.createElement(antd_1.Button, { onClick: () => update({ [key]: undefined }), size: "small", type: "danger", shape: "circle", icon: "close" }),
                ] },
                react_1.default.createElement(antd_1.List.Item.Meta, { title: title }),
                react_1.default.createElement(antd_1.Switch, { defaultChecked: true, onChange: (value) => update({ [key]: value }) })),
        ];
    }
}
const [enumKey, enumName] = [['enum', 'Enum'], ['enumNames', 'Enum Names']].map(([key, title]) => ({ node: { schema }, updateSchema: update }) => {
    if (schema.type !== 'string')
        return [];
    if (schema[key] === undefined) {
        return [
            react_1.default.createElement(antd_1.Menu.Item, { key: key, onClick: () => update({ [key]: [] }) }, title),
        ];
    }
    else {
        return [
            null,
            react_1.default.createElement(FormItemTemplate, { key: key, title: title, remove: () => update({ [key]: undefined }) },
                react_1.default.createElement(antd_1.Select, { mode: "tags", style: { width: '100%' }, onChange: (values) => update({ [key]: values }), value: schema[key] }, schema[key].map((a) => (react_1.default.createElement(antd_1.Select.Option, { key: a }, a))))),
        ];
    }
});
const formatOptions = ['date-time', 'email', 'hostname', 'ipv4', 'ipv6', 'uri'];
function format({ node: { schema }, updateSchema: update }) {
    const key = 'format';
    const title = 'Format';
    if (schema.type !== 'string')
        return [];
    if (schema[key] === undefined) {
        return [
            react_1.default.createElement(antd_1.Menu.Item, { key: key, onClick: () => update({ [key]: [] }) }, title),
        ];
    }
    else {
        return [
            null,
            react_1.default.createElement(FormItemTemplate, { key: key, title: title, remove: () => update({ [key]: undefined }) },
                react_1.default.createElement(antd_1.Select, { style: { width: '100%' }, onChange: (value) => update({ [key]: value }), value: schema[key] }, formatOptions.map((a) => (react_1.default.createElement(Option, { key: a }, a))))),
        ];
    }
}
class GroupsEditor extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.style = { width: '100%' };
        this.freeProperties = (total, groupName, groups) => {
            const otherGroupProperties = Object.keys(groups).filter(g => g !== groupName).reduce((acc, cur) => {
                acc = acc.concat(groups[cur].properties);
                return acc;
            }, []);
            return total.filter(p => otherGroupProperties.indexOf(p) < 0);
        };
        // props.value
        const groupNames = Object.keys(props.value || {});
        this.state = {
            value: props.value,
            groupNames,
            options: groupNames,
        };
    }
    componentWillReceiveProps(nextProps) {
        if (nextProps.value !== this.props.value) {
            const value = nextProps.value;
            const { options } = this.state;
            const groupNames = Object.keys(value) || {};
            const newOptions = groupNames.filter((a) => !options.includes(a));
            this.setState({
                value,
                groupNames,
                options: newOptions,
            });
        }
    }
    render() {
        const _a = this.props, { title, properties } = _a, rest = __rest(_a, ["title", "properties"]);
        const { options, value, groupNames } = this.state;
        return (react_1.default.createElement(FormItemTemplate, { title: title, remove: () => this.props.onChange(undefined) },
            react_1.default.createElement(antd_1.Select, Object.assign({ style: this.style, mode: "tags", tokenSeparators: [" "] }, rest, { value: groupNames, onChange: newGroupNames => {
                    const newValue = newGroupNames.reduce((acc, cur) => {
                        acc[cur] = value[cur] || { properties: [] };
                        return acc;
                    }, {});
                    this.props.onChange(newValue);
                }, onBlur: this.onBlur }), options.map(a => (react_1.default.createElement(Option, { key: a }, a)))),
            groupNames.map(groupName => (react_1.default.createElement(antd_1.Select, { style: this.style, mode: "multiple", tokenSeparators: [" "], value: value[groupName].properties, onChange: (v) => {
                    const newValue = Object.assign({}, value);
                    newValue[groupName].properties = v;
                    this.props.onChange(newValue);
                } }, this.freeProperties(properties, groupName, value).map(a => (react_1.default.createElement(Option, { key: a }, a))))))));
    }
}
function groups({ node: { schema, uiSchema }, updateUiSchema: update }) {
    const key = 'ui:groups';
    const title = 'Property Groups';
    if (schema.type !== 'object')
        return [];
    if (!uiSchema[key]) {
        return [
            react_1.default.createElement(antd_1.Menu.Item, { key: key, onClick: () => update({ [key]: [] }) }, title),
        ];
    }
    return [
        null,
        react_1.default.createElement(GroupsEditor, { key: key, properties: Object.keys(schema.properties) || [], title: title, value: uiSchema[key], onChange: value => update({ [key]: value }) })
    ];
}
class BasicEditor extends react_1.default.Component {
    static get key() {
        return 'basic-editor';
    }
    static get name() {
        return 'Basic';
    }
    static filter(node) {
        return node.schema;
    }
    name() {
        return null;
    }
    render() {
        const l = [
            type,
            title,
            description,
            required,
            widget,
            classNames,
            help,
            placeholder,
            enumKey,
            enumName,
            pattern,
            length,
            range,
            itemRange,
            uniqueItems,
            format,
            groups,
        ].map((f) => f(this.props));
        const addable = l.map((a) => a[0]).filter((a) => a);
        const editable = l.map((a) => a[1]).filter((a) => a);
        if (addable.length) {
            editable.push(react_1.default.createElement(antd_1.List.Item, { key: "addButton" },
                react_1.default.createElement(antd_1.Dropdown, { trigger: ['click'], overlay: react_1.default.createElement(antd_1.Menu, null, addable) },
                    react_1.default.createElement(antd_1.Button, { style: { width: '100%' }, type: "primary", icon: "plus" }))));
        }
        return react_1.default.createElement(antd_1.List, { itemLayout: "horizontal", dataSource: editable, renderItem: (a) => a });
    }
    _render() {
        return (react_1.default.createElement("form", { className: "ant-form ant-form-horizontal" },
            this.name(),
            react_1.default.createElement("fieldset", null,
                react_1.default.createElement("legend", null, "Schema"),
                this.title(),
                this.description()),
            react_1.default.createElement("fieldset", null,
                react_1.default.createElement("legend", null, "uiSchema"),
                this.widgets(),
                this.classNames(),
                this.help())));
    }
}
exports.default = BasicEditor;
//# sourceMappingURL=BasicEditor.js.map