"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const InlineEditor_1 = require("../InlineEditor");
const react_redux_1 = require("react-redux");
const antd_1 = require("antd");
const { getNodeByRjsfId } = require('../core');
const { TextArea } = antd_1.Input;
const ACTIVE_STYLE = { backgroundColor: '#bae7ff' };
class ExtendedInlineEditor extends InlineEditor_1.default {
    renderView() {
        return (react_1.default.createElement("span", { className: "fb-test", onClick: this.onStartEditing }, this.props.children));
    }
}
class InlineTextAreaEditor extends ExtendedInlineEditor {
    renderEditing() {
        return (react_1.default.createElement(TextArea, { ref: (r) => (this.input = r), value: this.state.value, onBlur: this.onCompleteEditing, onChange: this.onChange, autosize: true, onKeyUp: (e) => {
                if (e.keyCode === 27) {
                    this.onCancelEditing();
                }
            } }));
    }
}
const ButtonGroup = react_redux_1.connect(null, (dispatch, { id }) => ({
    select: () => dispatch({ type: 'ACTIVE_NODE_KEY_SET_BY_RJSF_ID', payload: id }),
    remove: () => dispatch({ type: 'TREE_REMOVE_NODE_BY_RJSF_ID', payload: id }),
}))((props) => {
    const { select, remove, id } = props;
    return (react_1.default.createElement(antd_1.Tooltip, { title: id, placement: "right" },
        react_1.default.createElement("a", { href: "#!" },
            react_1.default.createElement(antd_1.Icon, { onClick: select, type: "select" })),
        react_1.default.createElement(antd_1.Popconfirm, { title: `Remove ${id}?`, onConfirm: remove },
            react_1.default.createElement("a", { href: "#!" },
                react_1.default.createElement(antd_1.Icon, { type: "delete" })))));
});
function fieldTemplateConnector(FieldTemplate) {
    return react_redux_1.connect(({ tree: { present }, activeNodeKey, settings: { isInlineMode } }, { id }) => {
        const n = getNodeByRjsfId(present, id);
        const active = n && n.key === activeNodeKey;
        return { tree: present, active, isInlineMode };
    }, (dispatch, { id, schema, uiSchema }) => ({
        updateTitle: (title) => dispatch({
            type: 'TREE_UPDATE_NODE_BY_RJSF_ID',
            payload: { rjsfId: id, nodeUpdate: { schema: Object.assign(Object.assign({}, schema), { title }) } },
        }),
        updateDescription: (description) => dispatch({
            type: 'TREE_UPDATE_NODE_BY_RJSF_ID',
            payload: { rjsfId: id, nodeUpdate: { schema: Object.assign(Object.assign({}, schema), { description }) } },
        }),
        updateHelp: (help) => dispatch({
            type: 'TREE_UPDATE_NODE_BY_RJSF_ID',
            payload: { rjsfId: id, nodeUpdate: { uiSchema: Object.assign(Object.assign({}, uiSchema), { 'ui:help': help }) } },
        }),
    }))((props) => {
        const { id, label, description, help, schema, updateTitle, updateDescription, updateHelp, active, classNames, isInlineMode, } = props;
        if (!isInlineMode)
            return react_1.default.createElement(FieldTemplate, Object.assign({}, props));
        const labelElement = label && (react_1.default.createElement(ExtendedInlineEditor, { value: label, onChange: updateTitle }, label));
        const descriptionElement = description && (react_1.default.createElement(InlineTextAreaEditor, { value: description.props.description, onChange: updateDescription }, description));
        const helpElement = help && (react_1.default.createElement(ExtendedInlineEditor, { value: help.props.help, onChange: updateHelp }, help));
        return (react_1.default.createElement("div", { className: classNames, style: active ? ACTIVE_STYLE : null },
            ['object', 'array'].includes(schema.type) ? null : (react_1.default.createElement("div", { className: "pull-right" },
                ' ',
                react_1.default.createElement(ButtonGroup, { id: id }),
                ' ')),
            react_1.default.createElement(FieldTemplate, Object.assign({ _label: label, _description: description, _help: help }, props, { classNames: null, label: labelElement, description: descriptionElement, help: helpElement }))));
    });
}
exports.fieldTemplateConnector = fieldTemplateConnector;
function objectFieldTemplateConnector(ObjectFieldTemplate) {
    return react_redux_1.connect(({ tree: { present }, activeNodeKey, settings: { isInlineMode } }, { idSchema }) => {
        const n = idSchema && idSchema.$id && getNodeByRjsfId(present, idSchema.$id);
        const active = n && n.key === activeNodeKey;
        return { tree: present, active, isInlineMode };
    }, (dispatch, { idSchema, schema }) => ({
        updateTitle: (title) => dispatch({
            type: 'TREE_UPDATE_NODE_BY_RJSF_ID',
            payload: { rjsfId: idSchema.$id, nodeUpdate: { schema: Object.assign(Object.assign({}, schema), { title }) } },
        }),
        updateDescription: (description) => dispatch({
            type: 'TREE_UPDATE_NODE_BY_RJSF_ID',
            payload: { rjsfId: idSchema.$id, nodeUpdate: { schema: Object.assign(Object.assign({}, schema), { description }) } },
        }),
    }))((props) => {
        const { idSchema, title, description, updateTitle, updateDescription, active, isInlineMode } = props;
        if (!isInlineMode)
            return react_1.default.createElement(ObjectFieldTemplate, Object.assign({}, props));
        const titleElement = title && (react_1.default.createElement("span", null,
            react_1.default.createElement(ExtendedInlineEditor, { value: title, onChange: updateTitle }, title),
            react_1.default.createElement("span", { className: "pull-right" },
                ' ',
                react_1.default.createElement(ButtonGroup, { id: idSchema.$id }),
                ' ')));
        const descriptionElement = description && (react_1.default.createElement(InlineTextAreaEditor, { value: description, onChange: updateDescription }, description));
        return (react_1.default.createElement("div", { style: active ? ACTIVE_STYLE : null },
            react_1.default.createElement(ObjectFieldTemplate, Object.assign({ _title: title, _description: description }, props, { title: titleElement, description: descriptionElement }))));
    });
}
exports.objectFieldTemplateConnector = objectFieldTemplateConnector;
//# sourceMappingURL=connectors.js.map